User manual
==============

.. toctree::
   :maxdepth: 1

   input_data
   set_engine
   set_model
   inference
   run_parallel
   output
   plotting
   theta
   settings
   extra_params_file
   units
   confidence_intervals